@@ -3,20 +3,16 @@ from . import abstract, exceptions, typing
 from .abstract import (
     ADependency,
     ADependencyChecker,
-    ADependencyCPE,
     ADependencyCVE,
     ADependencyCVEs,
-    ADependencyCVEVersionMatcher,
     ADependencyGithubRelease,
     AGithubDependencyIssue,
     AGithubDependencyIssues)
 from .checker import (
     Dependency,
     DependencyChecker,
-    DependencyCPE,
     DependencyCVE,
     DependencyCVEs,
-    DependencyCVEVersionMatcher,
     DependencyGithubRelease,
     GithubDependencyIssue,
     GithubDependencyIssues)
@@ -28,20 +24,16 @@ __all__ = (
     "abstract",
     "ADependency",
     "ADependencyChecker",
-    "ADependencyCPE",
     "ADependencyCVE",
     "ADependencyCVEs",
-    "ADependencyCVEVersionMatcher",
     "ADependencyGithubRelease",
     "AGithubDependencyIssue",
     "AGithubDependencyIssues",
     "checker",
     "Dependency",
     "DependencyChecker",
-    "DependencyCPE",
     "DependencyCVE",
     "DependencyCVEs",
-    "DependencyCVEVersionMatcher",
     "DependencyGithubRelease",
     "GithubDependencyIssue",
     "GithubDependencyIssues",
