@@ -1,10 +1,8 @@
 
 from .checker import ADependencyChecker
 from .cves import (
-    ADependencyCPE,
     ADependencyCVE,
-    ADependencyCVEs,
-    ADependencyCVEVersionMatcher)
+    ADependencyCVEs)
 from .dependency import ADependency
 from .issues import AGithubDependencyIssue, AGithubDependencyIssues
 from .release import ADependencyGithubRelease
@@ -13,10 +11,8 @@ from .release import ADependencyGithubRelease
 __all__ = (
     "ADependency",
     "ADependencyChecker",
-    "ADependencyCPE",
     "ADependencyCVE",
     "ADependencyCVEs",
-    "ADependencyCVEVersionMatcher",
     "AGithubDependencyIssue",
     "AGithubDependencyIssues",
     "ADependencyGithubRelease")
